==> fengoffice_1.7.5.zip: fengoffice/language/es_es/calendar.php <==
<?php return array(
	'CAL_QUERY_GETEVENT_ERROR' => 'Error de la base de datos: Error al obtener evento por su id',
	'CAL_QUERY_SETEVENT_ERROR' => 'Error de la base de datos: Error al almacenar un evento',
	'CAL_SUBM_LOGOUT' => 'Log Out',
	'CAL_SUBM_LOGIN' => 'Log In',
	'CAL_SUBM_ADMINPAGE' => 'Admin Page',
	'CAL_SUBM_SEARCH' => 'Buscar',
	'CAL_SUBM_BACK_CALENDAR' => 'Atrás al calendario',
	'CAL_SUBM_VIEW_TODAY' => 'Ver eventos de hoy',
	'CAL_SUBM_ADD' => 'Añadir evento hoy',
	'CAL_MENU_BACK_CALENDAR' => 'Atrás al calendario',
	'CAL_MENU_NEWEVENT' => 'Evento nuevo',
	'CAL_MENU_BACK_EVENTS' => 'Volver a eventos',
	'CAL_MENU_GO' => 'Ir',
	'CAL_MENU_TODAY' => 'Hoy',
	'CAL_NO_READ_PERMISSION' => 'No tiene permisos para ver el evento',
	'CAL_NO_WRITE_PERMISSION' => 'No tiene permisos para añadir o editar eventos',
	'CAL_NO_EDITOTHERS_PERMISSION' => 'No tiene permisos para añadir o editar eventos de otros usuarios',
	'CAL_NO_EDITPAST_PERMISSION' => 'No tiene permisos para añadir o editar eventos',
	'CAL_NO_ACCOUNTS' => 'No se permiten usuarios, solo administrador.',
	'CAL_NO_MODIFY' => 'no se puede modificar',
	'CAL_NO_ANYTHING' => 'No tiene permisos en esta página',
	'CAL_NO_WRITE' => 'No tiene permisos para crear nuevos eventos',
	'CAL_MONDAY' => 'Lunes',
	'CAL_TUESDAY' => 'Martes',
	'CAL_WEDNESDAY' => 'Miercoles',
	'CAL_THURSDAY' => 'Jueves',
	'CAL_FRIDAY' => 'Viernes',
	'CAL_SATURDAY' => 'Sábado',
	'CAL_SUNDAY' => 'Domingo',
	'CAL_SHORT_MONDAY' => 'L',
	'CAL_SHORT_TUESDAY' => 'M',
	'CAL_SHORT_WEDNESDAY' => 'Mi',
	'CAL_SHORT_THURSDAY' => 'J',
	'CAL_SHORT_FRIDAY' => 'V',
	'CAL_SHORT_SATURDAY' => 'S',
	'CAL_SHORT_SUNDAY' => 'D',
	'CAL_JANUARY' => 'Enero',
	'CAL_FEBRUARY' => 'Febrero',
	'CAL_MARCH' => 'Marzo',
	'CAL_APRIL' => 'Abril',
	'CAL_MAY' => 'Mayo',
	'CAL_JUNE' => 'Junio',
	'CAL_JULY' => 'Julio',
	'CAL_AUGUST' => 'Agosto',
	'CAL_SEPTEMBER' => 'Septiembre',
	'CAL_OCTOBER' => 'Octubre',
	'CAL_NOVEMBER' => 'Noviembre',
	'CAL_DECEMBER' => 'Diciembre',
	'CAL_MORE_TIME_OPTIONS' => 'Mas opciones de tiempos',
	'CAL_REPEAT' => 'Repetir',
	'CAL_EVERY' => 'Cada',
	'CAL_REPEAT_FOREVER' => 'Repetir para siempre',
	'CAL_REPEAT_UNTIL' => 'Repetir hasta',
	'CAL_TIMES' => 'Veces',
	'CAL_HOLIDAY_EXPLAIN' => 'Hará que el evento se repita en ',
	'CAL_DURING' => 'Durante',
	'CAL_EVERY_YEAR' => 'Todos los años',
	'CAL_HOLIDAY_EXTRAOPTION' => 'O, como cae en la Última semana del mes, Marque aquí para hacer que el evento sea en el Último',
	'CAL_IN' => 'en',
	'CAL_PRIVATE_EVENT_EXPLAIN' => 'Esto es un evento privado',
	'CAL_SUBMIT_ITEM' => 'Enviar item',
	'CAL_MINUTES' => 'Minutos',
	'CAL_MINUTES_SHORT' => 'min',
	'CAL_TIME_AND_DURATION' => 'Fecha, hora y duración',
	'CAL_REPEATING_EVENT' => 'Evento Repetitivo',
	'CAL_EXTRA_OPTIONS' => 'Opciones Extra',
	'CAL_ONLY_TODAY' => 'Sólo este día',
	'CAL_DAILY_EVENT' => 'Repetir diariamente',
	'CAL_WEEKLY_EVENT' => 'Repetir semanalmente',
	'CAL_MONTHLY_EVENT' => 'Repetir mensualmente',
	'CAL_YEARLY_EVENT' => 'Repetir anualmente',
	'CAL_HOLIDAY_EVENT' => 'Repetir vacaciones',
	'CAL_UNKNOWN_TIME' => 'Tiempo de inicio desconocido',
	'CAL_ADDING_TO' => 'Añadiendo a',
	'CAL_ANON_ALIAS' => 'Alias',
	'CAL_EVENT_TYPE' => 'Tipo de evento',
	'CAL_DESCRIPTION' => 'Descripción',
	'CAL_DURATION' => 'Duración',
	'CAL_DATE' => 'Fecha',
	'CAL_NO_EVENTS_FOUND' => 'No se encontraron eventos',
	'CAL_NO_SUBJECT' => 'Sin título',
	'CAL_PRIVATE_EVENT' => 'Evento privado',
	'CAL_DELETE' => 'Borrar',
	'CAL_MODIFY' => 'Modificar',
	'CAL_NOT_SPECIFIED' => 'No Especificado',
	'CAL_FULL_DAY' => 'Todo el día',
	'CAL_HACKING_ATTEMPT' => 'Intento de hackeo - se almanenó la dirección IP',
	'CAL_TIME' => 'Hora',
	'CAL_HOURS' => 'Horas',
	'CAL_HOUR' => 'Hora',
	'CAL_ANONYMOUS' => 'Anónimo',
	'CAL_SELECT_TIME' => 'Selecctione tiempo de inicio',
	'event invitations' => 'Personas invitadas',
	'event invitations desc' => 'Invita al evento a las siguientes personas',
	'send new event notification' => 'Enviar notificación vía correo electrónico',
	'new event notification' => 'Nuevo Evento',
	'change event notification' => 'Modificación de evento',
	'deleted event notification' => 'Evento eliminado',
	'attendance' => '¿Va a participar?',
	'confirm attendance' => 'Confirma Asistencia',
	'maybe' => 'Quizás',
	'decide later' => 'Decidir después',
	'view event' => 'Ver evento',
	'new event created' => 'Evento creado',
	'event changed' => 'Evento modificado',
	'event deleted' => 'Evento eliminado',
	'calendar of' => 'Calendario de {0}',
	'all users' => 'Todos los Usuarios',
	'error delete event' => 'Error al eliminar evento',
  	'event invitation response' => 'Respuesta a invitación para evento',
  	'user will attend to event' => '{0} va a participar del evento.',
  	'user will not attend to event' => '{0} no va a participar del evento',  
  	'accept or reject invitation help, click on one of the links below' => 'Para aceptar o rechazar la invitación al evento, haga click en uno de los siguientes links',
  	'accept invitation' => 'Aceptar invitación',
	'reject invitation' => 'Rechazar invitación',
  	'invitation accepted' => 'Invitación aceptada',
	'invitation rejected' => 'Invitación rechazada',
	'days' => 'días',
	'weeks' => 'semanas',
	'months' => 'meses',
	'years' => 'años',
	'invitations' => 'Invitaciones',
	'pending response' => 'Respuesta pendiente',
	'participate' => 'Participa',
	'no invitations to this event' => 'No se enviaron invitaciones para este evento',
	'duration must be at least 15 minutes' => 'La duración debe ser al menos 15 minutos',
	'event dnx' => 'El evento requerido no existe',
	
	'also confirmed attendance' => 'También confirmaron asistencia',
  	'awaiting confirmation' => 'Esperando confirmación',
    'rejected invitation' => 'No asistirán',
	'who' => 'Quién',
  	'what' => 'Qué',

	'no subject' => 'Sin Asunto',
	'success import events' => 'Se importaron {0} eventos.',
	'no events to import' => 'No hay eventos para importar',
	'import events from file' => 'Importación de eventos desde archivo',
	'file should be in icalendar format' => 'El archivo debe tener formato iCalendar',
	'export calendar' => 'Exportación de calendario',
	'range of events' => 'Rango de eventos',
	'from date' => 'Desde',
	'to date' => 'Hasta',
	'success export calendar' => 'Se exportaron {0} eventos.',
	'calendar name desc' => 'Nombre para el calendario a exportar',
	'calendar will be exported in icalendar format' => 'El calendario se exportará en formato iCalendar.',
	'view date title' => 'l, d/m/Y',

	'copy this url in your calendar client software' => 'Copie esta url en su aplicación de calendario, para importar los eventos de este calendario',
	'import events from third party software' => 'Importe eventos desde otras aplicaciones',
	'subws' => 'Sub Esp.',
	'check to include sub ws' => 'Active esta casilla para incluír los sub espacios de trabajo en el link',
	'week short' => 'Sem.',
	'week number x' => 'Semana {0}',	
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_es/calendar.php <==
<?php return array(
	'CAL_QUERY_GETEVENT_ERROR' => 'Error de la base de datos: Error al obtener evento por su id',
	'CAL_QUERY_SETEVENT_ERROR' => 'Error de la base de datos: Error al almacenar un evento',
	'CAL_SUBM_LOGOUT' => 'Log Out',
	'CAL_SUBM_LOGIN' => 'Log In',
	'CAL_SUBM_ADMINPAGE' => 'Admin Page',
	'CAL_SUBM_SEARCH' => 'Buscar',
	'CAL_SUBM_BACK_CALENDAR' => 'Atrás al calendario',
	'CAL_SUBM_VIEW_TODAY' => 'Ver eventos de hoy',
	'CAL_SUBM_ADD' => 'Añadir evento hoy',
	'CAL_MENU_BACK_CALENDAR' => 'Atrás al calendario',
	'CAL_MENU_NEWEVENT' => 'Evento nuevo',
	'CAL_MENU_BACK_EVENTS' => 'Volver a eventos',
	'CAL_MENU_GO' => 'Ir',
	'CAL_MENU_TODAY' => 'Hoy',
	'CAL_NO_READ_PERMISSION' => 'No tiene permisos para ver el evento',
	'CAL_NO_WRITE_PERMISSION' => 'No tiene permisos para añadir o editar eventos',
	'CAL_NO_EDITOTHERS_PERMISSION' => 'No tiene permisos para añadir o editar eventos de otros usuarios',
	'CAL_NO_EDITPAST_PERMISSION' => 'No tiene permisos para añadir o editar eventos',
	'CAL_NO_ACCOUNTS' => 'No se permiten usuarios, solo administrador.',
	'CAL_NO_MODIFY' => 'no se puede modificar',
	'CAL_NO_ANYTHING' => 'No tiene permisos en esta página',
	'CAL_NO_WRITE' => 'No tiene permisos para crear nuevos eventos',
	'CAL_MONDAY' => 'Lunes',
	'CAL_TUESDAY' => 'Martes',
	'CAL_WEDNESDAY' => 'Miercoles',
	'CAL_THURSDAY' => 'Jueves',
	'CAL_FRIDAY' => 'Viernes',
	'CAL_SATURDAY' => 'Sábado',
	'CAL_SUNDAY' => 'Domingo',
	'CAL_SHORT_MONDAY' => 'L',
	'CAL_SHORT_TUESDAY' => 'M',
	'CAL_SHORT_WEDNESDAY' => 'Mi',
	'CAL_SHORT_THURSDAY' => 'J',
	'CAL_SHORT_FRIDAY' => 'V',
	'CAL_SHORT_SATURDAY' => 'S',
	'CAL_SHORT_SUNDAY' => 'D',
	'CAL_JANUARY' => 'Enero',
	'CAL_FEBRUARY' => 'Febrero',
	'CAL_MARCH' => 'Marzo',
	'CAL_APRIL' => 'Abril',
	'CAL_MAY' => 'Mayo',
	'CAL_JUNE' => 'Junio',
	'CAL_JULY' => 'Julio',
	'CAL_AUGUST' => 'Agosto',
	'CAL_SEPTEMBER' => 'Septiembre',
	'CAL_OCTOBER' => 'Octubre',
	'CAL_NOVEMBER' => 'Noviembre',
	'CAL_DECEMBER' => 'Diciembre',
	'CAL_MORE_TIME_OPTIONS' => 'Mas opciones de tiempos',
	'CAL_REPEAT' => 'Repetir',
	'CAL_EVERY' => 'Cada',
	'CAL_REPEAT_FOREVER' => 'Repetir para siempre',
	'CAL_REPEAT_UNTIL' => 'Repetir hasta',
	'CAL_TIMES' => 'Veces',
	'CAL_HOLIDAY_EXPLAIN' => 'Hará que el evento se repita en ',
	'CAL_DURING' => 'Durante',
	'CAL_EVERY_YEAR' => 'Todos los años',
	'CAL_HOLIDAY_EXTRAOPTION' => 'O, como cae en la Última semana del mes, Marque aquí para hacer que el evento sea en el Último',
	'CAL_IN' => 'en',
	'CAL_PRIVATE_EVENT_EXPLAIN' => 'Esto es un evento privado',
	'CAL_SUBMIT_ITEM' => 'Enviar item',
	'CAL_MINUTES' => 'Minutos',
	'CAL_MINUTES_SHORT' => 'min',
	'CAL_TIME_AND_DURATION' => 'Fecha, hora y duración',
	'CAL_REPEATING_EVENT' => 'Evento Repetitivo',
	'CAL_EXTRA_OPTIONS' => 'Opciones Extra',
	'CAL_ONLY_TODAY' => 'Sólo este día',
	'CAL_DAILY_EVENT' => 'Repetir diariamente',
	'CAL_WEEKLY_EVENT' => 'Repetir semanalmente',
	'CAL_MONTHLY_EVENT' => 'Repetir mensualmente',
	'CAL_YEARLY_EVENT' => 'Repetir anualmente',
	'CAL_HOLIDAY_EVENT' => 'Repetir vacaciones',
	'CAL_UNKNOWN_TIME' => 'Tiempo de inicio desconocido',
	'CAL_ADDING_TO' => 'Añadiendo a',
	'CAL_ANON_ALIAS' => 'Alias',
	'CAL_EVENT_TYPE' => 'Tipo de evento',
	'CAL_DESCRIPTION' => 'Descripción',
	'CAL_DURATION' => 'Duración',
	'CAL_DATE' => 'Fecha',
	'CAL_NO_EVENTS_FOUND' => 'No se encontraron eventos',
	'CAL_NO_SUBJECT' => 'Sin título',
	'CAL_PRIVATE_EVENT' => 'Evento privado',
	'CAL_DELETE' => 'Borrar',
	'CAL_MODIFY' => 'Modificar',
	'CAL_NOT_SPECIFIED' => 'No Especificado',
	'CAL_FULL_DAY' => 'Todo el día',
	'CAL_HACKING_ATTEMPT' => 'Intento de hackeo - se almanenó la dirección IP',
	'CAL_TIME' => 'Hora',
	'CAL_HOURS' => 'Horas',
	'CAL_HOUR' => 'Hora',
	'CAL_ANONYMOUS' => 'Anónimo',
	'CAL_SELECT_TIME' => 'Selecctione tiempo de inicio',
	'event invitations' => 'Personas invitadas',
	'event invitations desc' => 'Invita al evento a las siguientes personas',
	'send new event notification' => 'Enviar notificación vía correo electrónico',
	'new event notification' => 'Nuevo Evento',
	'change event notification' => 'Modificación de evento',
	'deleted event notification' => 'Evento eliminado',
	'attendance' => '¿Va a participar?',
	'confirm attendance' => 'Confirma Asistencia',
	'maybe' => 'Quizás',
	'decide later' => 'Decidir después',
	'view event' => 'Ver evento',
	'new event created' => 'Evento creado',
	'event changed' => 'Evento modificado',
	'event deleted' => 'Evento eliminado',
	'calendar of' => 'Calendario de {0}',
	'all users' => 'Todos los Usuarios',
	'error delete event' => 'Error al eliminar evento',
  	'event invitation response' => 'Respuesta a invitación para evento',
  	'user will attend to event' => '{0} va a participar del evento.',
  	'user will not attend to event' => '{0} no va a participar del evento',  
  	'accept or reject invitation help, click on one of the links below' => 'Para aceptar o rechazar la invitación al evento, haga click en uno de los siguientes links',
  	'accept invitation' => 'Aceptar invitación',
	'reject invitation' => 'Rechazar invitación',
  	'invitation accepted' => 'Invitación aceptada',
	'invitation rejected' => 'Invitación rechazada',
	'days' => 'días',
	'weeks' => 'semanas',
	'months' => 'meses',
	'years' => 'años',
	'invitations' => 'Invitaciones',
	'pending response' => 'Respuesta pendiente',
	'participate' => 'Participa',
	'no invitations to this event' => 'No se enviaron invitaciones para este evento',
	'duration must be at least 15 minutes' => 'La duración debe ser al menos 15 minutos',
	'event dnx' => 'El evento requerido no existe',
	
	'also confirmed attendance' => 'También confirmaron asistencia',
  	'awaiting confirmation' => 'Esperando confirmación',
    'rejected invitation' => 'No asistirán',
	'who' => 'Quién',
  	'what' => 'Qué',

	'no subject' => 'Sin Asunto',
	'success import events' => 'Se importaron {0} eventos.',
	'no events to import' => 'No hay eventos para importar',
	'import events from file' => 'Importación de eventos desde archivo',
	'file should be in icalendar format' => 'El archivo debe tener formato iCalendar',
	'export calendar' => 'Exportación de calendario',
	'range of events' => 'Rango de eventos',
	'from date' => 'Desde',
	'to date' => 'Hasta',
	'success export calendar' => 'Se exportaron {0} eventos.',
	'calendar name desc' => 'Nombre para el calendario a exportar',
	'calendar will be exported in icalendar format' => 'El calendario se exportará en formato iCalendar.',
	'view date title' => 'l, d/m/Y',

	'copy this url in your calendar client software' => 'Copie esta url en su aplicación de calendario, para importar los eventos de este calendario',
	'import events from third party software' => 'Importe eventos desde otras aplicaciones',
	'subws' => 'Sub Esp.',
	'check to include sub ws' => 'Active esta casilla para incluír los sub espacios de trabajo en el link',
	'week short' => 'Sem.',
	'week number x' => 'Semana {0}',	
        
        'could not connect to calendar' => 'No se pudo conectar al calendario.',
        'calendar sinchronization' => 'Sincronización de Google Calendar',
        'no calendars' => 'No hay calendarios',
        'name calendar' => 'Nombre',
        'users link' => 'Link del calendario',       
        'account gmail' => 'Cuenta de gmail',
        'password gmail' => 'Contraseña de gmail',
        'add calendar' => 'Agregar calendario',
        'add account' => 'Agregar cuenta',
        'new calendar' => 'Nuevo google calendar',
        'edit calendar' => 'Editar google calendar',
        'must enter a calendar name' => 'Debe introducir un nombre para el calendario',
        'must enter an calendar link' => 'Debe introducir el link del calendario',
        'success add calendar' => 'El calendario se ha creado correctamente',
        'success delete calendar' => 'El calendario se ha creado correctamente',
        'success edit calendar' => 'El calendario se ha modificado correctamente',
        'success add sync' => 'La sincronización se ha procesado correctamente',
        'success edit account gmail' => 'Cuenta de Gmail modificada correctamente',
        'success add account gmail' => 'Cuenta de Gmail creada correctamente',
        'must enter a account gmail' => 'Debe introducir una cuenta de Gmail',
        'must enter the password gmail' => 'Debe introducir su contraseña de gmail',
        'untitle event' => 'Evento sin título',
        'click sincronizar' => 'Haga clic en aquí si desea sincronizar los eventos de Feng con Google Calendar',
        'feng calendar' => 'Calendario de Feng',
        'import calendars' => 'Importar',
        'account has already' => 'La cuenta ya fue ingresada',
        'sync event feng' => 'Sincronizar todos los eventos de Feng',
        'list calendar' => 'Calendarios de Google Calendar',
        'check your account' => 'Verifique los datos de su cuenta',
); ?>
